WithOneRelated

Struct WithOneRelated 

pub struct WithOneRelated(pub Entity);
A wrapper over an Entity indicating that an entity should be added. This is intended to be used for hierarchical spawning via traits like SpawnableList and SpawnRelated.

Unlike WithRelated this only adds one entity.

Also see the children and related macros that abstract over the Spawn API.

let mut world = World::new();

let child1 = world.spawn(Name::new("Child1")).id();

world.spawn((
    Name::new("Root"),
    Children::spawn((
        // This adds the already existing entity as a child of Root.
        WithOneRelated(child1),
    )),
));

Tuple Fields

0: Entity