WithRelated

Struct WithRelated 

pub struct WithRelated<I>(pub I);
A SpawnableList that links already spawned entities to the root entity via relations of type I.

This is useful if the entity has already been spawned earlier or if you spawn multiple relationships link to the same entity at the same time. If you only need to do this for a single entity, consider using WithOneRelated.

let mut world = World::new();

let child2 = world.spawn(Name::new("Child2")).id();
let child3 = world.spawn(Name::new("Child3")).id();

world.spawn((
    Name::new("Root"),
    Children::spawn((
        Spawn(Name::new("Child1")),
        // This adds the already existing entities as children of Root.
        WithRelated::new([child2, child3]),
    )),
));

Tuple Fields

0: I

Implementations

Source

impl<I> WithRelated<I>

pub fn new(iter: impl IntoIterator<IntoIter = I>) -> WithRelated<I>

Creates a new WithRelated from a collection of entities.