Crate vifu_runtime

Crate vifu_runtime 

Small, stateful runtime primitives for embedding Vifu in Rust applications.

Add application behavior as Bevy plugins, dispatch RuntimeCommand values, and let the host execute the resulting effects.

Modules

prelude
Common imports for application runtime plugins.

Structs

EffectRequest
EffectRequestQueue
EffectResult
EffectResultQueue
HeadlessRuntime
RuntimeAdvance
RuntimeCommand
RuntimeCommandQueue
RuntimeEvent
RuntimeEventQueue
RuntimeSchedule
RuntimeSnapshot
RuntimeState
VifuRuntimePlugin