pub struct Discard {
pub entity: Entity,
}Expand description
Trigger emitted when a component is removed from an entity, regardless of whether or not it is later replaced.
Runs before the value is replaced, so you can still access the original component data.
See ComponentHooks::on_discard for more information.
Fields
entity: EntityThe entity that held this component before it was discarded.