pub struct Remove {
pub entity: Entity,
}Expand description
Trigger emitted when a component is removed from an entity, and runs before the component is
removed, so you can still access the component data.
See ComponentHooks::on_remove for more information.
Fields
entity: EntityThe entity this component was removed from.